@@ -3,17 +3,14 @@
     Project              : Knights
     Description          : Game board (scene)
     --------------------------------------------------------------------
-    Copyright            : (C) 2016 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2009-2011 by Miha Čančula (miha@noughmad.eu)
+    SPDX-FileCopyrightText: 2016 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2009-2011 Miha Čančula (miha@noughmad.eu)
 
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *                                                                         *
  *  This program is distributed in the hope that it will be useful,        *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
@@ -605,3 +602,5 @@ PieceType Board::getPromotedType() {
 	delete dialog;
 	return piece;
 }
+
+#include "moc_board.cpp"
