@@ -3,17 +3,14 @@
     Project              : Knights
     Description          : Game Dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2016-2018 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2009-2011 by Miha Čančula (miha@noughmad.eu)
+    SPDX-FileCopyrightText: 2016-2018 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2009-2011 Miha Čančula (miha@noughmad.eu)
 
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *                                                                         *
  *  This program is distributed in the hope that it will be useful,        *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
@@ -40,14 +37,21 @@
 #include "enginesettings.h"
 
 #include <QRandomGenerator>
-#include <QNetworkConfigurationManager>
 #include <QDialogButtonBox>
 
+#if QT_VERSION_MAJOR == 6
+#include <QNetworkInformation>
+#else
+#include <QNetworkConfigurationManager>
+#endif
+
 using namespace Knights;
 
 GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 	ui(new Ui::GameDialog()),
+#if QT_VERSION_MAJOR == 5
 	m_networkManager(new QNetworkConfigurationManager(this)),
+#endif
 	okButton(nullptr) {
 
 	QFrame* mainFrame = new QFrame(this);
@@ -130,9 +134,22 @@ GameDialog::GameDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f),
 	connect(ui->sbTimeIncrement, static_cast<void (QSpinBox::*)(int)> (&QSpinBox::valueChanged), this, &GameDialog::updateTimeEdits);
 	connect(ui->sbNumberOfMoves, static_cast<void (QSpinBox::*)(int)> (&QSpinBox::valueChanged), this, &GameDialog::updateTimeEdits);
 
+#if QT_VERSION_MAJOR == 6
+	bool hasNetworkInfo = QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
+
+	if (hasNetworkInfo) {
+		connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, [this](QNetworkInformation::Reachability newReachability) {
+			networkStatusChanged(newReachability == QNetworkInformation::Reachability::Online);
+		});
+
+		networkStatusChanged(QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online);
+	}
+#else
 	connect(m_networkManager, &QNetworkConfigurationManager::onlineStateChanged, this, &GameDialog::networkStatusChanged);
 
 	networkStatusChanged(m_networkManager->isOnline());
+#endif
+
 	updateTimeEdits();
 	player1SettingsChanged();
 	player2SettingsChanged();
@@ -324,11 +341,7 @@ void GameDialog::loadEngines() {
 	QStringList programs;
 	QList<EngineConfiguration> configs;
 	for (const QString& s : Settings::engineConfigurations()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-		const  QStringList l = s.split(QLatin1Char(':'), QString::SkipEmptyParts);
-#else
 		const  QStringList l = s.split(QLatin1Char(':'), Qt::SkipEmptyParts);
-#endif
 		EngineConfiguration e = EngineConfiguration(s);
 		if(!e.name.isEmpty()) {
 			programs << e.name;
@@ -369,3 +382,5 @@ void GameDialog::checkOkButton() {
 	okButton->setEnabled(true);
 	okButton->setToolTip(i18n("Start the game."));
 }
+
+#include "moc_gamedialog.cpp"
